@@ -1,4 +1,4 @@
-use serde::{Deserialize, Deserializer, Serialize, Serializer};
+use serde::{Deserialize, Deserializer, Serializer};
 
 pub const AUTOTOOLS: &str = "autotools";
 pub const CMAKE: &str = "cmake";
@@ -20,38 +20,23 @@ pub enum FlatpakBuildSystem {
     Simple,
 }
 
-pub fn serialize_to_string<S>(x: &FlatpakBuildSystem, s: S) -> Result<S::Ok, S::Error>
-where
-    S: Serializer,
-{
-    s.serialize_str(&x.to_string())
-}
-
-pub fn deserialize_from_string<'de, D>(deserializer: D) -> Result<FlatpakBuildSystem, D::Error>
-where
-    D: Deserializer<'de>,
-{
-    let buf = String::deserialize(deserializer)?;
-
-    FlatpakBuildSystem::from_string(&buf).map_err(serde::de::Error::custom)
-}
-
 impl Default for FlatpakBuildSystem {
     fn default() -> Self {
-        FlatpakBuildSystem::Simple
+        FlatpakBuildSystem::Autotools
     }
 }
 impl FlatpakBuildSystem {
     pub fn to_string(&self) -> String {
         match &self {
-            Autotools => AUTOTOOLS.to_string(),
-            CMake => CMAKE.to_string(),
-            CMakeNinja => CMAKE_NINJA.to_string(),
-            QMake => QMAKE.to_string(),
-            Meson => MESON.to_string(),
-            Simple => SIMPLE.to_string(),
+            FlatpakBuildSystem::Autotools => AUTOTOOLS.to_string(),
+            FlatpakBuildSystem::CMake => CMAKE.to_string(),
+            FlatpakBuildSystem::CMakeNinja => CMAKE_NINJA.to_string(),
+            FlatpakBuildSystem::QMake => QMAKE.to_string(),
+            FlatpakBuildSystem::Meson => MESON.to_string(),
+            FlatpakBuildSystem::Simple => SIMPLE.to_string(),
         }
     }
+
     pub fn from_string(build_sys: &str) -> Result<FlatpakBuildSystem, String> {
         if build_sys == AUTOTOOLS {
             return Ok(FlatpakBuildSystem::Autotools);
@@ -73,4 +58,26 @@ impl FlatpakBuildSystem {
         }
         Err(format!("Invalid build system {}.", build_sys))
     }
+
+    pub fn serialize<S>(x: &Option<FlatpakBuildSystem>, s: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        if let Some(build_system) = x {
+            return s.serialize_str(&build_system.to_string());
+        }
+        panic!("This should not happen.");
+    }
+
+    pub fn deserialize<'de, D>(deserializer: D) -> Result<Option<FlatpakBuildSystem>, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        let buf = String::deserialize(deserializer)?;
+
+        match FlatpakBuildSystem::from_string(&buf) {
+            Ok(b) => Ok(Some(b)),
+            Err(e) => Err(e).map_err(serde::de::Error::custom),
+        }
+    }
 }
